@@ -161,7 +161,10 @@ def plot_repair(row, data_dir, with_plotly=True):
                 ax.autoscale()
                 ax.axis("equal")
                 plt.title(f"{row.name}")
-                plt.suptitle(plane + "mtype:" + row.mtype)
+                if hasattr(row, "mtype") and isinstance(row.mtype, str):
+                    plt.suptitle(plane + "mtype:" + row.mtype)
+                else:
+                    plt.suptitle(plane)
                 pdf.savefig()
                 plt.close()
 
@@ -260,7 +263,10 @@ def make_collage(
                 plt.figure(figsize=figsize)
                 ax = plt.gca()
                 for shift, morph_name in enumerate(batch):
-                    layer_pos = layer_centers[int(mtype[1]) - 1]
+                    try:
+                        layer_pos = layer_centers[int(mtype[1]) - 1]
+                    except (TypeError, IndexError):
+                        layer_pos = 0
                     neuron = load_morphology(_df.loc[morph_name, "morph_path"])
 
                     translate = [shift * separation, layer_pos, 0.0]
@@ -331,11 +337,17 @@ def make_release(  # pylint: disable=unused-argument
 
     _m = []
     for name in df.loc[df["is_valid"]].index:
+        if "mtype" in df.columns and isinstance(df.loc[name, "mtype"], str):
+            mtype = df.loc[name, "mtype"]
+            layer = df.loc[name, "mtype"][1]
+        else:
+            mtype = ""
+            layer = ""
         _m.append(
             MorphInfo(
                 name=name,
-                mtype=df.loc[name, "mtype"],
-                layer=df.loc[name, "mtype"][1],
+                mtype=mtype,
+                layer=layer,
                 use_dendrite=df.loc[name, "has_basal"],
                 use_axon=df.loc[name, "has_axon"],
             )
