@@ -24,6 +24,7 @@ from morphology_workflows.tasks.curation import PlotMorphologies
 from morphology_workflows.tasks.curation import Recenter
 from morphology_workflows.tasks.curation import Resample
 from morphology_workflows.tasks.curation import Sanitize
+from morphology_workflows.tasks.fetch import FetchMorphologies
 from morphology_workflows.tasks.repair import CollectAnnotated
 from morphology_workflows.tasks.repair import FixZeroDiameters
 from morphology_workflows.tasks.repair import MakeCollage
@@ -49,6 +50,10 @@ def save_reduced_df(
     ].rename_axis(index="morph_name").reset_index().to_csv(out_dir / df_path, index=False)
 
 
+class Fetch(FetchMorphologies):
+    """Fetch morphologies from the given source."""
+
+
 class Curate(ValidationWorkflow):
     """Run Curation phase.
 
